pub enum FallbackError<E> {
Inner(E),
FallbackFailed(E),
}Expand description
Error type for the fallback service.
Variants
Inner(E)
The inner service failed and no fallback was applied (predicate didn’t match), or the error was transformed via the exception strategy.
FallbackFailed(E)
The fallback service itself failed.
Implementations
Sourceimpl<E> FallbackError<E>
impl<E> FallbackError<E>
Sourcepub fn is_fallback_failed(&self) -> bool
pub fn is_fallback_failed(&self) -> bool
Returns true if the fallback itself failed.
Sourcepub fn into_inner(self) -> E
pub fn into_inner(self) -> E
Converts into the inner error.
Sourcepub fn map<F, U>(self, f: F) -> FallbackError<U>where
F: FnOnce(E) -> U,
pub fn map<F, U>(self, f: F) -> FallbackError<U>where
F: FnOnce(E) -> U,
Maps the inner error using the provided function.