HandleResponsePredicate

Type Alias HandleResponsePredicate 

pub type HandleResponsePredicate<Res> = Arc<dyn Fn(&Res) -> bool + Send + Sync>;
Predicate to determine if a successful response should trigger the fallback.

When this predicate returns true, the response is treated as if the service had failed, and the fallback strategy is applied.

Aliased Type

pub struct HandleResponsePredicate<Res> { /* private fields */ }