FallbackStrategy

Enum FallbackStrategy 

pub enum FallbackStrategy<Req, Res, E> {
    Value(Res),
    ValueFn(ValueFn<Res>),
    FromError(FromErrorFn<Res, E>),
    FromRequestError(FromRequestErrorFn<Req, Res, E>),
    Service(ServiceFn<Req, Res, E>),
    Exception(ExceptionFn<E>),
}
The strategy used to produce a fallback response.

Variants



Value(Res)

Return a static value (cloned for each fallback).



ValueFn(ValueFn<Res>)

Generate a value using a function (no Clone required).



FromError(FromErrorFn<Res, E>)

Compute a response from the error.



FromRequestError(FromRequestErrorFn<Req, Res, E>)

Compute a response from both the request and error.



Service(ServiceFn<Req, Res, E>)

Call a backup service asynchronously. The function takes the request and returns a future.



Exception(ExceptionFn<E>)

Transform the error into a different error (still fails, but with transformed error).